Attribute VB_Name = "basDeclaration"
Option Explicit

'------------------------------------------------------------
' Return codes for PageMasterRun function.
Public Const PAGEMASTER_OK = 0              ' No errors
Public Const PAGEMASTER_ERR = 1             ' Unspecified error
Public Const PAGEMASTER_ERR_BADKEY = 2      ' Bad license key
Public Const PAGEMASTER_ERR_DIRCREATE = 3   ' Failed to create the output file/directory
Public Const PAGEMASTER_ERR_BADFILENAME = 4  ' Bad input filename or path
Public Const PAGEMASTER_ERR_NOOUTFILE = 5    ' Output file not specified
Public Const PAGEMASTER_ERR_READINGPDF = 6   ' error reading the input document
Public Const PAGEMASTER_ERR_PASSWORD = 7     ' document is secured. bad password.
Public Const PAGEMASTER_ERR_WRITE = 8        ' error writing an output file or folder
Public Const PAGEMASTER_ERR_NOINPUTFILES = 9 ' no input files found

'------------------------------------------------------------
' 'mode' identifier passed in PageMasterCallback.
' The 'mode' can be used to determine whether a message is an error or
' a progress message.
Public Const PAGEMASTER_ERROR = 1        ' Show the error message
Public Const PAGEMASTER_MSG = 2          ' Report the message
Public Const PAGEMASTER_GETPASS = 3      ' Get the password
Public Const PAGEMASTER_OUT_FILENAME = 4 ' Reports the Saved File Names


'------------------------------------------------------------
' API function declarations

'------------------------------------------------------------
' Initialize PageMaster with registration and license information.
' Although PageMasterInit is typically called only once (e.g. during the program
' startup), it can also be called multiple times without side effects.
'
' The first parameter is your username, the second parameter is your company name,
' and the last parameter is the license key supplied with your registration information.
'------------------------------------------------------------
Public Declare Function PageMasterInit Lib "..\..\lib\pagemaster.dll" _
    (ByVal user_name As String, _
     ByVal company As String, _
     ByVal license_key As String) As Integer

'------------------------------------------------------------
' Execute PageMaster command string.
'
' PageMasterRun can be called multiple times to process PDF documents or folders
' with PDF documents. The function is completely thread safe, so it is possible to
' run many PageMaster threads at the same time.
'
' @param command_str PageMaster command string. For a detailed explanation of
' all options and syntax, please refer to section 4 in PageMaster SDK Manual.
'
' @param funct (optional) a pointer to the callback function used to report error
' as well as other messages.
'
' @param user_data (optional) a pointer to custom data that you may want to
' pass to the callback function. NULL if you don't need to pass custom data.
'
' @return error code. A non-zero value indicates that an error was encountered.
'------------------------------------------------------------
Public Declare Function PageMasterRun Lib "..\..\lib\pagemaster.dll" _
    (ByVal command_str As String, _
     ByVal callback_funct As Long, _
     ByVal user_data As Long) As Integer


